pub struct NodeProfile {
pub mobility: NodeMobility,
pub resources: NodeResources,
pub can_parent: bool,
pub prefer_leaf: bool,
pub parent_priority: u8,
}Expand description
Node profile combining mobility and resources
Fields
mobility: NodeMobilityMobility type
resources: NodeResourcesResource capacity
can_parent: boolWhether this node can act as a parent
prefer_leaf: boolWhether this node prefers to be a leaf (never parent)
parent_priority: u8Priority for parent selection (higher = more preferred)
Implementations
Sourceimpl NodeProfile
impl NodeProfile
Sourcepub fn static_node(resources: NodeResources) -> Self
pub fn static_node(resources: NodeResources) -> Self
Create a static node profile (command post, fixed infrastructure)
Sourcepub fn mobile_node(resources: NodeResources) -> Self
pub fn mobile_node(resources: NodeResources) -> Self
Create a mobile node profile (vehicle, soldier)
Sourcepub fn semi_mobile_node(resources: NodeResources) -> Self
pub fn semi_mobile_node(resources: NodeResources) -> Self
Create a semi-mobile node profile (relocatable but stable)
Sourcepub fn is_parent_candidate(&self, requirements: &ParentingRequirements) -> bool
pub fn is_parent_candidate(&self, requirements: &ParentingRequirements) -> bool
Check if this node should be considered as a parent candidate