pub enum HierarchyLevel {
Platform = 0,
Squad = 1,
Platoon = 2,
Company = 3,
}Expand description
Hierarchy level in military command structure
Variants
Platform = 0
Individual platform (vehicle, soldier, etc.)
Squad = 1
Squad level (typically 4-13 platforms)
Platoon = 2
Platoon level (typically 2-4 squads)
Company = 3
Company level (typically 2-4 platoons)
Implementations
Sourceimpl HierarchyLevel
impl HierarchyLevel
Sourcepub fn parent(&self) -> Option<HierarchyLevel>
pub fn parent(&self) -> Option<HierarchyLevel>
Get the parent level in the hierarchy
Sourcepub fn child(&self) -> Option<HierarchyLevel>
pub fn child(&self) -> Option<HierarchyLevel>
Get the child level in the hierarchy
Sourcepub fn can_be_parent_of(&self, child: &HierarchyLevel) -> bool
pub fn can_be_parent_of(&self, child: &HierarchyLevel) -> bool
Check if this level can be a parent of another level A level can be parent if it’s at least one level higher in hierarchy